@@ -169,6 +169,19 @@ lambda_.GoFunction(self, "handler",
 )
 ```
 
+By default this construct doesn't use any Go module proxies. This is contrary to
+a standard Go installation, which would use the Google proxy by default. To
+recreate that behavior, do the following:
+
+```python
+lambda_.GoFunction(self, "GoFunction",
+    entry="app/cmd/api",
+    bundling=lambda.BundlingOptions(
+        go_proxies=[lambda_.GoFunction.GOOGLE_GOPROXY, "direct"]
+    )
+)
+```
+
 ## Command hooks
 
 It is  possible to run additional commands by specifying the `commandHooks` prop:
@@ -293,6 +306,7 @@ import aws_cdk.core
         "environment": "environment",
         "forced_docker_bundling": "forcedDockerBundling",
         "go_build_flags": "goBuildFlags",
+        "go_proxies": "goProxies",
     },
 )
 class BundlingOptions:
@@ -308,6 +322,7 @@ class BundlingOptions:
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         forced_docker_bundling: typing.Optional[builtins.bool] = None,
         go_build_flags: typing.Optional[typing.Sequence[builtins.str]] = None,
+        go_proxies: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''(experimental) Bundling options.
 
@@ -320,6 +335,7 @@ class BundlingOptions:
         :param environment: (experimental) Environment variables defined when go runs. Default: - no environment variables are defined.
         :param forced_docker_bundling: (experimental) Force bundling in a Docker container even if local bundling is possible. Default: - false
         :param go_build_flags: (experimental) List of additional flags to use while building. For example: ['ldflags "-s -w"'] Default: - none
+        :param go_proxies: (experimental) What Go proxies to use to fetch the packages involved in the build. Pass a list of proxy addresses in order, and/or the string ``'direct'`` to attempt direct access. By default this construct uses no proxies, but a standard Go install would use the Google proxy by default. To recreate that behavior, do the following:: new lambda.GoFunction(this, 'GoFunction', { entry: 'app/cmd/api', bundling: { goProxies: [lambda.GoFunction.GOOGLE_GOPROXY, 'direct'], }, }); Default: - Direct access
 
         :stability: experimental
         :exampleMetadata: infused
@@ -329,9 +345,7 @@ class BundlingOptions:
             lambda_.GoFunction(self, "handler",
                 entry="app/cmd/api",
                 bundling=lambda.BundlingOptions(
-                    environment={
-                        "HELLO": "WORLD"
-                    }
+                    docker_image=DockerImage.from_build("/path/to/Dockerfile")
                 )
             )
         '''
@@ -347,6 +361,7 @@ class BundlingOptions:
                 environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
                 forced_docker_bundling: typing.Optional[builtins.bool] = None,
                 go_build_flags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                go_proxies: typing.Optional[typing.Sequence[builtins.str]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -359,6 +374,7 @@ class BundlingOptions:
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
             check_type(argname="argument forced_docker_bundling", value=forced_docker_bundling, expected_type=type_hints["forced_docker_bundling"])
             check_type(argname="argument go_build_flags", value=go_build_flags, expected_type=type_hints["go_build_flags"])
+            check_type(argname="argument go_proxies", value=go_proxies, expected_type=type_hints["go_proxies"])
         self._values: typing.Dict[str, typing.Any] = {}
         if asset_hash is not None:
             self._values["asset_hash"] = asset_hash
@@ -378,6 +394,8 @@ class BundlingOptions:
             self._values["forced_docker_bundling"] = forced_docker_bundling
         if go_build_flags is not None:
             self._values["go_build_flags"] = go_build_flags
+        if go_proxies is not None:
+            self._values["go_proxies"] = go_proxies
 
     @builtins.property
     def asset_hash(self) -> typing.Optional[builtins.str]:
@@ -513,6 +531,30 @@ class BundlingOptions:
         result = self._values.get("go_build_flags")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def go_proxies(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) What Go proxies to use to fetch the packages involved in the build.
+
+        Pass a list of proxy addresses in order, and/or the string ``'direct'`` to
+        attempt direct access.
+
+        By default this construct uses no proxies, but a standard Go install would
+        use the Google proxy by default. To recreate that behavior, do the following::
+
+           lambda_.GoFunction(self, "GoFunction",
+               entry="app/cmd/api",
+               bundling=lambda.BundlingOptions(
+                   go_proxies=[lambda_.GoFunction.GOOGLE_GOPROXY, "direct"]
+               )
+           )
+
+        :default: - Direct access
+
+        :stability: experimental
+        '''
+        result = self._values.get("go_proxies")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -540,7 +582,7 @@ class GoFunction(
         lambda_.GoFunction(self, "handler",
             entry="app/cmd/api",
             bundling=lambda.BundlingOptions(
-                go_build_flags=["-ldflags \"-s -w\""]
+                docker_image=DockerImage.from_build("/path/to/Dockerfile")
             )
         )
     '''
@@ -736,6 +778,15 @@ class GoFunction(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="GOOGLE_GOPROXY")
+    def GOOGLE_GOPROXY(cls) -> builtins.str:
+        '''(experimental) The address of the Google Go proxy.
+
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.sget(cls, "GOOGLE_GOPROXY"))
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-lambda-go.GoFunctionProps",
@@ -882,7 +933,7 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
             lambda_.GoFunction(self, "handler",
                 entry="app/cmd/api",
                 bundling=lambda.BundlingOptions(
-                    go_build_flags=["-ldflags \"-s -w\""]
+                    docker_image=DockerImage.from_build("/path/to/Dockerfile")
                 )
             )
         '''
